@@ -18,9 +18,9 @@
 from RestrictedPython import _compat
 
 
-if _compat.IS_PY2:
+if _compat.IS_PY2:  # pragma: PY2
     import __builtin__ as builtins
-else:
+else:  # pragma: PY3
     # Do not attempt to use this package on Python2.7 as there
     # might be backports for this package such as future.
     import builtins
@@ -109,7 +109,7 @@ _safe_exceptions = [
     'ZeroDivisionError',
 ]
 
-if _compat.IS_PY2:
+if _compat.IS_PY2:  # pragma: PY2
     _safe_names.extend([
         'basestring',
         'cmp',
@@ -121,7 +121,7 @@ if _compat.IS_PY2:
     _safe_exceptions.extend([
         'StandardError',
     ])
-else:
+else:  # pragma: PY3
     _safe_names.extend([
         '__build_class__',  # needed to define new classes
     ])
@@ -264,9 +264,12 @@ def safer_getattr(object, name, default=None, getattr=getattr):
     http://lucumr.pocoo.org/2016/12/29/careful-with-str-format/
 
     """
-    if isinstance(object, _compat.basestring) and name == 'format':
+    if name in ('format', 'format_map') and (
+            isinstance(object, _compat.basestring) or (
+            isinstance(object, type)
+            and issubclass(object, _compat.basestring))):
         raise NotImplementedError(
-            'Using format() on a %s is not safe.' % object.__class__.__name__)
+            'Using the string format* methods is not safe')
     if name.startswith('_'):
         raise AttributeError(
             '"{name}" is an invalid attribute name because it '
