@@ -2,6 +2,7 @@ from RestrictedPython import compile_restricted_function
 from RestrictedPython import PrintCollector
 from RestrictedPython import safe_builtins
 from RestrictedPython._compat import IS_PY38_OR_GREATER
+from RestrictedPython._compat import IS_PY310_OR_GREATER
 from types import FunctionType
 
 
@@ -210,9 +211,15 @@ def test_compile_restricted_function_handle_SyntaxError():
     )
 
     assert result.code is None
-    assert result.errors == (
-        "Line 1: SyntaxError: unexpected EOF while parsing at statement: 'a('",
-    )
+    if IS_PY310_OR_GREATER:
+        assert result.errors == (
+            "Line 1: SyntaxError: '(' was never closed at statement: 'a('",
+        )
+    else:
+        assert result.errors == (
+            "Line 1: SyntaxError: unexpected EOF while parsing at statement:"
+            " 'a('",
+        )
 
 
 def test_compile_restricted_function_invalid_syntax():
@@ -230,7 +237,11 @@ def test_compile_restricted_function_invalid_syntax():
     assert len(result.errors) == 1
     error_msg = result.errors[0]
 
-    if IS_PY38_OR_GREATER:
+    if IS_PY310_OR_GREATER:
+        assert error_msg.startswith(
+            "Line 1: SyntaxError: cannot assign to literal here. Maybe "
+        )
+    elif IS_PY38_OR_GREATER:
         assert error_msg.startswith(
             "Line 1: SyntaxError: cannot assign to literal at statement:"
         )
